@@ -1,72 +1,77 @@
-( cd opt/kde/lib ; rm -rf libcompoundviewer.so.4 )
-( cd opt/kde/lib ; ln -sf libcompoundviewer.so.4.2.0 libcompoundviewer.so.4 )
+( cd opt/kde/share/doc/HTML/en/kalzium ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kalzium ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kig ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/blinken ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/blinken ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kiten ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kiten ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kturtle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/parley ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/parley ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kstars ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kstars ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/marble ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/marble ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/step ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/step ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/klettres ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/klettres ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kmplot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kmplot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/khangman ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/khangman ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kanagram ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kanagram ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kalgebra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kalgebra ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kgeography ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kgeography ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ktouch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ktouch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kbruch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libanalitza.so )
+( cd opt/kde/lib ; ln -sf libanalitza.so.4 libanalitza.so )
+( cd opt/kde/lib ; rm -rf libkdeeduui.so.4 )
+( cd opt/kde/lib ; ln -sf libkdeeduui.so.4.3.0 libkdeeduui.so.4 )
+( cd opt/kde/lib ; rm -rf libavogadro-kalzium.so.0 )
+( cd opt/kde/lib ; ln -sf libavogadro-kalzium.so.0.9.3 libavogadro-kalzium.so.0 )
+( cd opt/kde/lib ; rm -rf libSatLib.so.4 )
+( cd opt/kde/lib ; ln -sf libSatLib.so.4.3.0 libSatLib.so.4 )
+( cd opt/kde/lib ; rm -rf libmarblewidget.so )
+( cd opt/kde/lib ; ln -sf libmarblewidget.so.4 libmarblewidget.so )
 ( cd opt/kde/lib ; rm -rf libkiten.so )
 ( cd opt/kde/lib ; ln -sf libkiten.so.4 libkiten.so )
 ( cd opt/kde/lib ; rm -rf libcompoundviewer.so )
 ( cd opt/kde/lib ; ln -sf libcompoundviewer.so.4 libcompoundviewer.so )
-( cd opt/kde/lib ; rm -rf libmarblewidget.so.4 )
-( cd opt/kde/lib ; ln -sf libmarblewidget.so.4.2.0 libmarblewidget.so.4 )
-( cd opt/kde/lib ; rm -rf libscience.so.4 )
-( cd opt/kde/lib ; ln -sf libscience.so.4.2.0 libscience.so.4 )
-( cd opt/kde/lib ; rm -rf libkdeeduui.so.4 )
-( cd opt/kde/lib ; ln -sf libkdeeduui.so.4.2.0 libkdeeduui.so.4 )
-( cd opt/kde/lib ; rm -rf libavogadro-kalzium.so.0 )
-( cd opt/kde/lib ; ln -sf libavogadro-kalzium.so.0.8.0 libavogadro-kalzium.so.0 )
-( cd opt/kde/lib ; rm -rf libSatLib.so.4 )
-( cd opt/kde/lib ; ln -sf libSatLib.so.4.2.0 libSatLib.so.4 )
-( cd opt/kde/lib ; rm -rf libanalitza.so )
-( cd opt/kde/lib ; ln -sf libanalitza.so.4 libanalitza.so )
-( cd opt/kde/lib ; rm -rf libkeduvocdocument.so )
-( cd opt/kde/lib ; ln -sf libkeduvocdocument.so.4 libkeduvocdocument.so )
-( cd opt/kde/lib ; rm -rf libanalitza.so.4 )
-( cd opt/kde/lib ; ln -sf libanalitza.so.4.2.0 libanalitza.so.4 )
-( cd opt/kde/lib ; rm -rf libSatLib.so )
-( cd opt/kde/lib ; ln -sf libSatLib.so.4 libSatLib.so )
-( cd opt/kde/lib ; rm -rf libmarblewidget.so )
-( cd opt/kde/lib ; ln -sf libmarblewidget.so.4 libmarblewidget.so )
-( cd opt/kde/lib ; rm -rf libkeduvocdocument.so.4 )
-( cd opt/kde/lib ; ln -sf libkeduvocdocument.so.4.2.0 libkeduvocdocument.so.4 )
-( cd opt/kde/lib ; rm -rf libkdeeduui.so )
-( cd opt/kde/lib ; ln -sf libkdeeduui.so.4 libkdeeduui.so )
-( cd opt/kde/lib ; rm -rf libkiten.so.4 )
-( cd opt/kde/lib ; ln -sf libkiten.so.4.2.0 libkiten.so.4 )
 ( cd opt/kde/lib ; rm -rf libscience.so )
 ( cd opt/kde/lib ; ln -sf libscience.so.4 libscience.so )
 ( cd opt/kde/lib ; rm -rf libavogadro-kalzium.so )
 ( cd opt/kde/lib ; ln -sf libavogadro-kalzium.so.0 libavogadro-kalzium.so )
-( cd opt/kde/share/doc/HTML/en/kig ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kig ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/step ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/step ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kalzium ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kalzium ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/khangman ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/khangman ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kiten ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kiten ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kalgebra ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kalgebra ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kanagram ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kanagram ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kturtle ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kturtle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kbruch ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kbruch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kmplot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kmplot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kstars ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kstars ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ktouch ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ktouch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/marble ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/marble ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/parley ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/parley ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/klettres ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/klettres ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kgeography ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kgeography ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/blinken ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/blinken ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kwordquiz ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libmarblewidget.so.4 )
+( cd opt/kde/lib ; ln -sf libmarblewidget.so.4.3.0 libmarblewidget.so.4 )
+( cd opt/kde/lib ; rm -rf libkeduvocdocument.so.4 )
+( cd opt/kde/lib ; ln -sf libkeduvocdocument.so.4.3.0 libkeduvocdocument.so.4 )
+( cd opt/kde/lib ; rm -rf libcompoundviewer.so.4 )
+( cd opt/kde/lib ; ln -sf libcompoundviewer.so.4.3.0 libcompoundviewer.so.4 )
+( cd opt/kde/lib ; rm -rf libkdeeduui.so )
+( cd opt/kde/lib ; ln -sf libkdeeduui.so.4 libkdeeduui.so )
+( cd opt/kde/lib ; rm -rf libkeduvocdocument.so )
+( cd opt/kde/lib ; ln -sf libkeduvocdocument.so.4 libkeduvocdocument.so )
+( cd opt/kde/lib ; rm -rf libkiten.so.4 )
+( cd opt/kde/lib ; ln -sf libkiten.so.4.3.0 libkiten.so.4 )
+( cd opt/kde/lib ; rm -rf libSatLib.so )
+( cd opt/kde/lib ; ln -sf libSatLib.so.4 libSatLib.so )
+( cd opt/kde/lib ; rm -rf libanalitza.so.4 )
+( cd opt/kde/lib ; ln -sf libanalitza.so.4.3.0 libanalitza.so.4 )
+( cd opt/kde/lib ; rm -rf libscience.so.4 )
+( cd opt/kde/lib ; ln -sf libscience.so.4.3.0 libscience.so.4 )
+#%% begin initialize kdeedu-4.3.1
+if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
+	/bin/bash /opt/kde/bin/plamo_update_kde.sh
+fi
+#%% end
